@@ -3,6 +3,7 @@
 提供图表上传和文件存储功能
 """
 
+import logging
 import warnings
 from pathlib import Path
 from typing import Any, Optional, Union
@@ -16,6 +17,10 @@ from .storage import StorageService
 # 缩略图相关导入
 from .thumbnail import generate_thumbnail
 
+# 配置logging - 库默认使用NullHandler，让用户决定是否启用日志
+logger = logging.getLogger("lims2")
+logger.addHandler(logging.NullHandler())
+
 __all__ = [
     # 版本信息
     "__version__",
