@@ -15,11 +15,13 @@ from .oss_base import OSSMixin
 from .thumbnail import generate_thumbnail
 from .utils import (
     clean_plotly_data,
+    detect_task_hash,
     get_file_size,
     handle_api_response,
     make_safe_filename,
     read_file_content,
     round_floats,
+    validate_task_hash,
 )
 
 logger = logging.getLogger("lims2.chart")
@@ -54,6 +56,7 @@ class ChartService(OSSMixin):
         precision: Optional[int] = None,
         generate_thumbnail: Optional[bool] = None,
         file_name: Optional[str] = None,
+        task_hash: Optional[str] = None,
     ) -> dict[str, Any]:
         """上传图表
 
@@ -64,11 +67,12 @@ class ChartService(OSSMixin):
             sample_id: 样本 ID（可选）
             chart_type: 图表类型（可选）
             description: 图表描述（可选）
-            contrast: 对比策略（可选）
+            contrast: 对比策略（可选，有 task_hash 时在 OSS 路径中被忽略，但仍会上报到 API）
             analysis_node: 分析节点名称（可选）
             precision: 浮点数精度控制，保留小数位数（0-10，默认3）
             generate_thumbnail: 是否生成缩略图，None时使用配置中的auto_generate_thumbnail
             file_name: 自定义文件名（仅对字典数据有效，文件上传使用文件本身的名称）
+            task_hash: Nextflow task hash（格式：xx/xxxxxx），不指定时自动检测
 
         Returns:
             上传结果
@@ -78,6 +82,15 @@ class ChartService(OSSMixin):
             chart_name, project_id, data_source, precision
         )
 
+        # 自动检测或验证 task_hash
+        if task_hash is None:
+            task_hash = detect_task_hash()
+        elif task_hash and not validate_task_hash(task_hash):
+            raise ValueError(
+                f"无效的 task_hash 格式: {task_hash}，"
+                "应为 xx/xxxxxx（2位/6位十六进制字符）"
+            )
+
         # 构建请求数据
         request_data = self._build_request_data(
             chart_name,
@@ -87,6 +100,7 @@ class ChartService(OSSMixin):
             sample_id,
             contrast,
             analysis_node,
+            task_hash,
         )
 
         # 根据数据源类型处理
@@ -138,6 +152,7 @@ class ChartService(OSSMixin):
         sample_id: Optional[str],
         contrast: Optional[str],
         analysis_node: Optional[str],
+        task_hash: Optional[str] = None,
     ) -> dict[str, Any]:
         """构建请求数据字典"""
         request_data = {
@@ -154,6 +169,8 @@ class ChartService(OSSMixin):
             request_data["contrast"] = contrast
         if analysis_node:
             request_data["analysis_node"] = analysis_node
+        if task_hash:
+            request_data["task_hash"] = task_hash
 
         return request_data
 
@@ -222,6 +239,7 @@ class ChartService(OSSMixin):
             request_data.get("analysis_node"),
             request_data.get("contrast"),
             request_data.get("sample_id"),
+            request_data.get("task_hash"),
         )
         bucket = self._get_oss_bucket(request_data["project_id"])
 
@@ -318,6 +336,7 @@ class ChartService(OSSMixin):
             request_data.get("analysis_node"),
             request_data.get("contrast"),
             request_data.get("sample_id"),
+            request_data.get("task_hash"),
         )
 
         # 读取文件内容
@@ -357,30 +376,43 @@ class ChartService(OSSMixin):
         analysis_node: Optional[str] = None,
         contrast: Optional[str] = None,
         sample_id: Optional[str] = None,
+        task_hash: Optional[str] = None,
     ) -> str:
         """构建图表的OSS键名
 
+        根据是否提供 task_hash 使用不同的路径策略：
+        - 有 task_hash：biochart/{env}/{project_id}/{analysis_node}/{bucket}/{suffix}/{filename}
+        - 无 task_hash：biochart/{env}/{project_id}/{analysis_node}/{contrast}/{sample_id}/{filename}
+
         Args:
             project_id: 项目ID（必需）
             filename: 文件名（必需）
             analysis_node: 分析节点名称（可选）
-            contrast: 对比策略（可选）
-            sample_id: 样本ID（可选）
+            contrast: 对比策略（可选，有 task_hash 时在 OSS 路径中被忽略，但仍会上报到 API）
+            sample_id: 样本ID（可选，有 task_hash 时被忽略）
+            task_hash: Nextflow task hash（格式：xx/xxxxxx）
 
         Returns:
-            str: OSS键名，格式为biochart/{env}/project_id/[analysis_node/][contrast/][sample_id/]filename
+            str: OSS键名
             - 环境前缀：生产环境使用media，测试环境使用test
-            - 参数顺序与路径构建顺序一致：project → analysis → contrast → sample → filename
         """
         # 使用环境相关的路径前缀
         env_prefix = self._get_oss_path_prefix()
         parts = ["biochart", env_prefix, project_id]
+
         if analysis_node:
             parts.append(analysis_node)
-        if contrast:
-            parts.append(contrast)
-        if sample_id:
-            parts.append(sample_id)
+
+        if task_hash:
+            # 策略 A：有 task_hash，用 task_hash 替代 contrast/sample_id
+            parts.extend(task_hash.split("/"))
+        else:
+            # 策略 B：原有路径方案
+            if contrast:
+                parts.append(contrast)
+            if sample_id:
+                parts.append(sample_id)
+
         parts.append(filename)
         return "/".join(parts)
 
@@ -440,6 +472,7 @@ class ChartService(OSSMixin):
                     request_data.get("analysis_node"),
                     request_data.get("contrast"),
                     request_data.get("sample_id"),
+                    request_data.get("task_hash"),
                 )
                 bucket = self._get_oss_bucket(request_data["project_id"])
                 content_type = f"image/{self.config.thumbnail_format}"
