@@ -3,16 +3,12 @@
 from typing import Optional
 
 import requests
-import urllib3
 
 from .chart import ChartService
 from .config import Config
 from .exceptions import ConfigError
 from .storage import StorageService
 
-# 禁用 urllib3 的 SSL 警告，因为我们在内网环境中使用，用户可以根据需要启用 SSL 验证
-urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
-
 
 class Lims2Client:
     """Lims2 SDK 主客户端
@@ -50,9 +46,6 @@ class Lims2Client:
         self.session = requests.Session()
         self.session.headers.update(self.config.get_headers())
 
-        # 配置SSL验证
-        self.session.verify = self.config.verify_ssl
-
         # 直接初始化服务
         self.chart = ChartService(self)
         self.storage = StorageService(self)
