@@ -3,6 +3,7 @@
 提取图表服务和存储服务的共同OSS操作逻辑
 """
 
+import logging
 import time
 from typing import Any
 
@@ -11,6 +12,8 @@ import oss2
 from .network import network_retry
 from .utils import handle_api_response
 
+logger = logging.getLogger("lims2.oss_base")
+
 
 class OSSMixin:
     """OSS操作混入类
@@ -30,11 +33,16 @@ class OSSMixin:
         Returns:
             str: 环境相关的路径前缀
                 - 生产环境 (api-v2): "media"
+                - 预发布环境 (gray): "gray"
                 - 测试环境 (其他): "test"
         """
         # 检查API URL是否包含"api-v2"
-        is_production = "api-v2" in self.config.api_url
-        return "media" if is_production else "test"
+        if "api-v2" in self.config.api_url:
+            return "media"
+        elif "gray" in self.config.api_url:
+            return "gray"
+
+        return "test"
 
     @network_retry(max_retries=3, base_delay=1.0, max_delay=60.0)
     def _get_sts_token(self, project_id: str) -> dict[str, Any]:
@@ -69,33 +77,95 @@ class OSSMixin:
             if time.time() - cached_data["cache_time"] < 10 * 60:  # 10分钟内有效
                 return {k: v for k, v in cached_data.items() if k != "cache_time"}
 
-        # 从 API 获取新的 STS 凭证
+        # 尝试从 STS Agent 获取（如果配置了）
+        if self.config.sts_agent_url:
+            try:
+                token_data = self._fetch_sts_from_agent(project_id)
+                logger.debug("成功从 STS Agent 获取凭证")
+                return self._cache_and_return_token(cache_key, token_data)
+            except Exception as e:
+                logger.warning(f"从 STS Agent 获取凭证失败: {e}，回退到主 API")
+
+        # 从主 API 获取（默认方式或回退）
+        token_data = self._fetch_sts_from_main_api(project_id)
+        logger.debug("从主 API 获取凭证")
+        return self._cache_and_return_token(cache_key, token_data)
+
+    def _parse_sts_response(self, result: dict) -> dict[str, Any]:
+        """解析 STS API 响应，提取凭证信息
+
+        Args:
+            result: API 响应结果
+
+        Returns:
+            dict[str, Any]: 标准化的凭证信息，包含 cache_time
+        """
+        raw_data = result.get("record", result)
+        return {
+            "access_key_id": raw_data.get("AccessKeyId"),
+            "access_key_secret": raw_data.get("AccessKeySecret"),
+            "security_token": raw_data.get("SecurityToken"),
+            "endpoint": self.config.oss_endpoint,
+            "bucket_name": self.config.oss_bucket_name,
+            "cache_time": time.time(),
+        }
+
+    def _fetch_sts_from_agent(self, project_id: str) -> dict[str, Any]:
+        """从 STS Agent 服务获取凭证
+
+        Args:
+            project_id: 项目 ID
+
+        Returns:
+            dict[str, Any]: 凭证信息
+
+        Raises:
+            Exception: 请求失败时抛出异常
+        """
+        params = {"team_id": self.config.team_id} if self.config.team_id else {}
+        response = self.session.get(
+            self.config.sts_agent_url,
+            params=params,
+            timeout=self.config.timeout,
+        )
+        result = handle_api_response(response, "从STS Agent获取凭证")
+        return self._parse_sts_response(result)
+
+    def _fetch_sts_from_main_api(self, project_id: str) -> dict[str, Any]:
+        """从主 API 获取 STS 凭证
+
+        Args:
+            project_id: 项目 ID
+
+        Returns:
+            dict[str, Any]: 凭证信息
+
+        Raises:
+            APIError: 请求失败时抛出异常
+        """
         params = {"team_id": self.config.team_id} if self.config.team_id else {}
         response = self.session.get(
             f"{self.config.api_url}/get_data/aliyun_sts/",
             params=params,
             timeout=self.config.timeout,
         )
+        result = handle_api_response(response, "从主API获取STS凭证")
+        return self._parse_sts_response(result)
 
-        result = handle_api_response(response, "获取STS凭证")
-        raw_data = result.get("record", result)
+    def _cache_and_return_token(
+        self, cache_key: str, token_data: dict[str, Any]
+    ) -> dict[str, Any]:
+        """缓存凭证并返回（去除时间戳）
 
-        # 构建标准化的凭证信息
-        token_data = {
-            "access_key_id": raw_data.get("AccessKeyId"),
-            "access_key_secret": raw_data.get("AccessKeySecret"),
-            "security_token": raw_data.get("SecurityToken"),
-            "endpoint": self.config.oss_endpoint,
-            "bucket_name": self.config.oss_bucket_name,
-            "cache_time": time.time(),  # 添加缓存时间戳
-        }
+        Args:
+            cache_key: 缓存键
+            token_data: 包含 cache_time 的凭证数据
 
-        # 缓存凭证并返回（返回时去除时间戳）
+        Returns:
+            dict[str, Any]: 去除 cache_time 的凭证数据
+        """
         self._sts_cache[cache_key] = token_data
-
-        # 检查缓存大小，清理过期项目以防止内存泄漏
         self._cleanup_cache()
-
         return {k: v for k, v in token_data.items() if k != "cache_time"}
 
     def _cleanup_cache(self) -> None:
@@ -153,9 +223,11 @@ class OSSMixin:
         """带重试的OSS对象上传"""
         return bucket.put_object(oss_key, data, headers=headers or {})
 
-    @network_retry(max_retries=3, base_delay=1.0, max_delay=60.0)
     def _get_object_meta_with_retry(self, bucket, oss_key):
-        """带重试的OSS对象元数据获取"""
+        """OSS对象元数据获取
+
+        注意：不使用重试装饰器，因为404是正常的业务逻辑
+        """
         return bucket.get_object_meta(oss_key)
 
     @network_retry(max_retries=3, base_delay=1.0, max_delay=60.0)
@@ -167,7 +239,40 @@ class OSSMixin:
             oss_key, file_path, progress_callback=progress_callback
         )
 
-    @network_retry(max_retries=3, base_delay=1.0, max_delay=60.0)
     def _object_exists_with_retry(self, bucket, oss_key):
-        """带重试的OSS对象存在性检查"""
-        return bucket.object_exists(oss_key)
+        """OSS对象存在性检查
+
+        注意：文件不存在是正常的业务逻辑，不应该重试
+        """
+        try:
+            return bucket.object_exists(oss_key)
+        except Exception:
+            # 任何异常都认为文件不存在
+            return False
+
+    def _check_file_exists_and_same_size(
+        self, bucket, oss_key, local_size: int
+    ) -> bool:
+        """检查OSS文件是否存在且大小相同
+
+        Args:
+            bucket: OSS bucket对象
+            oss_key: OSS文件键名
+            local_size: 本地文件大小
+
+        Returns:
+            bool: 文件存在且大小相同返回True
+        """
+        try:
+            if not self._object_exists_with_retry(bucket, oss_key):
+                return False
+
+            # 获取远程文件元数据
+            meta = self._get_object_meta_with_retry(bucket, oss_key)
+            remote_size = int(meta.headers.get("Content-Length", 0))
+
+            # 比较文件大小
+            return remote_size == local_size
+        except Exception:
+            # 如果检查失败，为了安全起见，认为文件不存在
+            return False
