@@ -13,11 +13,13 @@ from .exceptions import APIError
 from .network import network_retry
 from .oss_base import OSSMixin
 from .utils import (
+    detect_task_hash,
     format_file_size,
     get_file_size,
     get_temp_dir,
     handle_api_response,
     make_safe_filename,
+    validate_task_hash,
 )
 
 logger = logging.getLogger("lims2.storage")
@@ -66,6 +68,7 @@ class StorageService(OSSMixin):
         description: Optional[str] = None,
         progress_callback: Optional[Callable] = None,
         base_path: Optional[str] = None,
+        task_hash: Optional[str] = None,
     ) -> dict[str, Any]:
         """上传单个文件到 OSS
 
@@ -75,10 +78,11 @@ class StorageService(OSSMixin):
             analysis_node: 分析节点名称
             file_category: 文件分类（如 'results', 'plot_data'）。若不指定且文件名以'report'开头的HTML文件会自动设为'report'
             key: 自定义 OSS 键名，不提供则自动生成
-            sample_id: 样本 ID（可选）
+            sample_id: 样本 ID（可选，有 task_hash 时在 OSS 路径中被忽略，但仍会上报到 API）
             description: 文件描述（可选）
             progress_callback: 进度回调函数，签名为 callback(consumed_bytes, total_bytes)
-            base_path: OSS 中的基础路径（可选）
+            base_path: OSS 中的基础路径（可选，有 task_hash 时在 OSS 路径中被忽略）
+            task_hash: Nextflow task hash（格式：xx/xxxxxx），不指定时自动检测
 
         Returns:
             dict[str, Any]: 上传结果，包含文件信息和 OSS 键名
@@ -99,24 +103,31 @@ class StorageService(OSSMixin):
         if not file_path.exists():
             raise FileNotFoundError(f"文件不存在: {file_path}")
 
+        # 自动检测或验证 task_hash
+        if task_hash is None:
+            task_hash = detect_task_hash()
+        elif task_hash and not validate_task_hash(task_hash):
+            raise ValueError(
+                f"无效的 task_hash 格式: {task_hash}，"
+                "应为 xx/xxxxxx（2位/6位十六进制字符）"
+            )
+
         # 智能检测 HTML 报告文件
         if file_category is None:
             filename_lower = file_path.name.lower()
             if filename_lower.startswith("report") and filename_lower.endswith(".html"):
                 file_category = "report"
 
-        # 构建 OSS 键名：biofile/{env}/project_id/[base_path/]filename
+        # 构建 OSS 键名
         if not key:
-            # 如果没有指定 base_path，对单文件上传使用 analysis_node/sample_id 作为默认路径
-            if base_path is None:
-                path_parts = []
-                if analysis_node:
-                    path_parts.append(analysis_node)
-                if sample_id:
-                    path_parts.append(sample_id)
-                base_path = "/".join(path_parts) if path_parts else None
-
-            key = self._build_oss_key(project_id, file_path.name, base_path)
+            key = self._build_oss_key(
+                project_id,
+                file_path.name,
+                base_path,
+                analysis_node,
+                sample_id,
+                task_hash,
+            )
 
         # 获取 OSS bucket
         bucket = self._get_oss_bucket(project_id)
@@ -139,6 +150,7 @@ class StorageService(OSSMixin):
             file_category or "result",
             sample_id,
             description,
+            task_hash,
         )
 
     def upload_directory(
@@ -151,6 +163,7 @@ class StorageService(OSSMixin):
         recursive: bool = True,
         base_path: Optional[str] = None,
         progress_callback: Optional[Callable] = None,
+        task_hash: Optional[str] = None,
     ) -> list[dict[str, Any]]:
         """批量上传目录中的所有文件
 
@@ -159,10 +172,11 @@ class StorageService(OSSMixin):
             project_id: 项目 ID
             analysis_node: 分析节点名称
             file_category: 文件分类
-            sample_id: 样本 ID（可选）
+            sample_id: 样本 ID（可选，有 task_hash 时在 OSS 路径中被忽略，但仍会上报到 API）
             recursive: 是否递归上传子目录（默认 True）
-            base_path: OSS 中的基础路径（可选）
+            base_path: OSS 中的基础路径（可选，有 task_hash 时在 OSS 路径中被忽略）
             progress_callback: 进度回调函数，接收(current, total, filename)参数
+            task_hash: Nextflow task hash（格式：xx/xxxxxx），不指定时自动检测
 
         Returns:
             list[dict[str, Any]]: 每个文件的上传结果列表
@@ -192,6 +206,15 @@ class StorageService(OSSMixin):
         if not dir_path.is_dir():
             raise ValueError(f"路径不是目录: {dir_path}")
 
+        # 自动检测或验证 task_hash（在目录级别检测一次）
+        if task_hash is None:
+            task_hash = detect_task_hash()
+        elif task_hash and not validate_task_hash(task_hash):
+            raise ValueError(
+                f"无效的 task_hash 格式: {task_hash}，"
+                "应为 xx/xxxxxx（2位/6位十六进制字符）"
+            )
+
         # 收集所有文件（递归或非递归）
         pattern = "**/*" if recursive else "*"
         files = [f for f in dir_path.glob(pattern) if f.is_file()]
@@ -214,11 +237,20 @@ class StorageService(OSSMixin):
                     project_id,
                     path_with_dir,
                     base_path,
+                    analysis_node,
+                    sample_id,
+                    task_hash,
                 )
 
-                # 上传单个文件（key已经包含完整路径，不需要再传base_path）
+                # 上传单个文件（key已经包含完整路径，传递task_hash以跳过重复检测）
                 result = self.upload_file(
-                    file_path, project_id, analysis_node, file_category, key, sample_id
+                    file_path,
+                    project_id,
+                    analysis_node,
+                    file_category,
+                    key,
+                    sample_id,
+                    task_hash=task_hash,  # 传递已检测的 task_hash，避免重复检测
                 )
                 results.append(result)
             except Exception as e:
@@ -333,19 +365,23 @@ class StorageService(OSSMixin):
         project_id: str,
         filename: str,
         base_path: Optional[str] = None,
+        analysis_node: Optional[str] = None,
+        sample_id: Optional[str] = None,
+        task_hash: Optional[str] = None,
     ) -> str:
         """构建 OSS 文件键名
 
-        生成规则：
-        - 基础路径：biofile/{env}/project_id/[base_path/]
-        - 环境前缀：生产环境使用media，测试环境使用test
-        - 文件名：确定性命名，相同输入产生相同文件名
-        - 始终保持目录结构
+        根据是否提供 task_hash 使用不同的路径策略：
+        - 有 task_hash：biofile/{env}/{project_id}/{analysis_node}/{bucket}/{suffix}/{filename}
+        - 无 task_hash：biofile/{env}/{project_id}/{base_path}/{filename}
 
         Args:
             project_id: 项目 ID
             filename: 文件名或相对路径
-            base_path: OSS 中的基础路径（可选）
+            base_path: OSS 中的基础路径（可选，有 task_hash 时在 OSS 路径中被忽略）
+            analysis_node: 分析节点名称（可选）
+            sample_id: 样本ID（可选，有 task_hash 时在 OSS 路径中被忽略）
+            task_hash: Nextflow task hash（格式：xx/xxxxxx）
 
         Returns:
             str: OSS 键名
@@ -354,14 +390,28 @@ class StorageService(OSSMixin):
             >>> self._build_oss_key("proj_001", "data.csv", base_path="results")
             "biofile/media/proj_001/results/data.csv"  # 生产环境
 
-            >>> self._build_oss_key("proj_001", "subdir/file.txt", "results")
-            "biofile/test/proj_001/results/subdir/file.txt"  # 测试环境
+            >>> self._build_oss_key("proj_001", "data.csv", task_hash="2f/0075a6")
+            "biofile/media/proj_001/2f/0075a6/data.csv"  # 有 task_hash 时
         """
         # 使用环境相关的路径前缀
         env_prefix = self._get_oss_path_prefix()
         parts = ["biofile", env_prefix, project_id]
-        if base_path:
-            parts.append(base_path)
+
+        if task_hash:
+            # 策略 A：有 task_hash，用 task_hash 替代 base_path/sample_id
+            if analysis_node:
+                parts.append(analysis_node)
+            parts.extend(task_hash.split("/"))
+        else:
+            # 策略 B：原有路径方案
+            if base_path:
+                parts.append(base_path)
+            elif analysis_node or sample_id:
+                # 如果没有 base_path，用 analysis_node/sample_id 作为默认路径
+                if analysis_node:
+                    parts.append(analysis_node)
+                if sample_id:
+                    parts.append(sample_id)
 
         path_obj = Path(filename)
         if len(path_obj.parts) > 1:
@@ -449,6 +499,7 @@ class StorageService(OSSMixin):
         file_category: str,
         sample_id: Optional[str],
         description: Optional[str],
+        task_hash: Optional[str] = None,
     ) -> dict[str, Any]:
         """在后端数据库创建文件上传记录
 
@@ -460,6 +511,7 @@ class StorageService(OSSMixin):
             file_category: 文件分类
             sample_id: 样本 ID（可选）
             description: 文件描述（可选）
+            task_hash: Nextflow task hash（格式：xx/xxxxxx）
 
         Returns:
             dict[str, Any]: 包含文件信息的结果，OSS 上传成功但记录失败时包含 error 字段
@@ -481,6 +533,8 @@ class StorageService(OSSMixin):
             "file_category": file_category,
             "analysis_node": analysis_node,
         }
+        if task_hash:
+            result["task_hash"] = task_hash
 
         # 记录到数据库
         record_data = {
@@ -495,6 +549,8 @@ class StorageService(OSSMixin):
             "team_id": self.config.team_id,
             "token": self.config.token,
         }
+        if task_hash:
+            record_data["task_hash"] = task_hash
 
         response = self.session.post(
             f"{self.config.api_url}/get_data/biofile/record_file_upload/",
