@@ -5,7 +5,7 @@ import os
 import re
 from decimal import ROUND_HALF_UP, Decimal
 from pathlib import Path
-from typing import Any, Union
+from typing import Any, Optional, Union
 
 import orjson
 import requests
@@ -249,6 +249,49 @@ def get_temp_dir(custom_dir: str = None, purpose: str = "oss-upload") -> str:
     return fallback
 
 
+def detect_task_hash() -> Optional[str]:
+    """从当前工作目录检测 Nextflow task hash
+
+    检测逻辑：从当前目录路径中匹配 `work/{xx}/{xxxxxx...}` 模式，
+    提取 hashLog 格式：`xx/xxxxxx`（前 2 位 + 后 6 位）
+
+    Returns:
+        task hash（格式：xx/xxxxxx），如果未检测到则返回 None
+
+    Example:
+        >>> # 在 /path/to/work/2f/0075a6xxx/output 目录中
+        >>> detect_task_hash()
+        '2f/0075a6'
+        >>> # 在普通目录中
+        >>> detect_task_hash()
+        None
+    """
+    cwd = os.getcwd()
+    # 匹配 work/xx/xxxxxx 模式（至少 6 个十六进制字符）
+    pattern = r"/work/([0-9a-f]{2})/([0-9a-f]{6})"
+    match = re.search(pattern, cwd.lower())
+    if match:
+        return f"{match.group(1)}/{match.group(2)}"
+    return None
+
+
+def validate_task_hash(task_hash: str) -> bool:
+    """验证 task hash 格式
+
+    格式要求: xx/xxxxxx（2位/6位，共9字符，全部为十六进制字符）
+
+    Args:
+        task_hash: 要验证的 task hash
+
+    Returns:
+        True 如果格式有效，False 否则
+    """
+    if not task_hash:
+        return True  # 可选参数，空值有效
+    pattern = r"^[0-9a-f]{2}/[0-9a-f]{6}$"
+    return bool(re.match(pattern, task_hash.lower()))
+
+
 def clean_plotly_data(data: dict) -> dict:
     """优化Plotly数据中的template以减少文件大小
 
